"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.CSSProcessedProps = void 0;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const compatCategories = ['native', 'web'];
const displayCategories = ['text', 'block'];
const propagationCategories = ['flow', 'retain'];
/**
 * An object representing categorized style props. Props are categorized
 * depending on their inheritability (flow, retain), target (block, text)
 * and (react) native support (native, web).
 */

class CSSProcessedProps {
  constructor() {
    _defineProperty(this, "native", void 0);

    _defineProperty(this, "web", void 0);

    this.native = this.newCompatCategory();
    this.web = this.newCompatCategory();
  }

  newCompatCategory() {
    return {
      block: {
        retain: {},
        flow: {}
      },
      text: {
        retain: {},
        flow: {}
      }
    };
  }

  withProperty(propertyName, propertyValue, {
    compatCategory,
    displayCategory,
    propagationCategory
  }) {
    if (propertyValue !== null) {
      this[compatCategory][displayCategory][propagationCategory][propertyName] = propertyValue;
    }

    return this;
  }
  /**
   * Create a new processed prop object by merging the 'overriders' parameters
   * into this object.
   *
   * @param overriders - The processed props which will be merged into this
   * processed prop. Rightmost props will override leftmost props.
   */


  merge(...overriders) {
    const next = new CSSProcessedProps();

    for (const compat of compatCategories) {
      for (const display of displayCategories) {
        for (const propagation of propagationCategories) {
          next[compat][display][propagation] = { ...this[compat][display][propagation],
            ...overriders.map(o => o[compat][display][propagation]).reduce((p, c) => ({ ...p,
              ...c
            }), {})
          };
        }
      }
    }

    return next;
  }

  static new() {
    return new CSSProcessedProps();
  }

}

exports.CSSProcessedProps = CSSProcessedProps;
//# sourceMappingURL=CSSProcessedProps.js.map